coef.mcmc <- 
function(object, ...)
{
    dclone:::coef.mcmc.list(as.mcmc.list(object), ...)
}
